@@ -1,11 +1,12 @@
 package App::PDFUtils;
 
-our $DATE = '2017-04-09'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2017-04-22'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
+#use Log::Any '$log';
 
 use Perinci::Object;
 
@@ -78,15 +79,15 @@ sub add_pdf_password {
         IPC::System::Options::system(
             {log => 1, capture_stdout => \$stdout, capture_stderr => \$stderr},
             "qpdf", "--encrypt", $args{password}, $args{password}, 128, "--", $f, $tempf);
-            my $err = $?;# ? Proc::ChildError::explain_child_error() : '';
-            if ($err && $stderr =~ /: invalid password$/) {
-                $envres->add_result(412, "File already encrypted", {item_id=>$f});
-                next FILE;
-            } elsif ($err) {
-                $stderr =~ s/\R//g;
-                $envres->add_result(500, $stderr, {item_id=>$f});
-                next FILE;
-            }
+        my $err = $?;# ? Proc::ChildError::explain_child_error() : '';
+        if ($err && $stderr =~ /: invalid password$/) {
+            $envres->add_result(412, "File already encrypted", {item_id=>$f});
+            next FILE;
+        } elsif ($err) {
+            $stderr =~ s/\R//g;
+            $envres->add_result(500, $stderr, {item_id=>$f});
+            next FILE;
+        }
 
       BACKUP:
         {
@@ -181,13 +182,16 @@ sub remove_pdf_password {
                 "qpdf", "--password=$p", "--decrypt", $f, $tempf);
             my $err = $?;# ? Proc::ChildError::explain_child_error() : '';
             if ($err && $stderr =~ /: invalid password$/) {
+                #$log->tracef("D1");
                 unlink $tempf; # just to make sure
                 next PASSWORD;
             } elsif ($err) {
+                #$log->tracef("D2");
                 $stderr =~ s/\R//g;
                 $envres->add_result(500, $stderr, {item_id=>$f});
                 next FILE;
             }
+            last;
         }
         unless (-f $tempf) {
             $envres->add_result(412, "No passwords can be successfully used on $f", {item_id=>$f});
@@ -227,7 +231,7 @@ App::PDFUtils - Command-line utilities related to PDF files
 
 =head1 VERSION
 
-This document describes version 0.001 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2017-04-09.
+This document describes version 0.002 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2017-04-22.
 
 =head1 SYNOPSIS
 
@@ -360,10 +364,10 @@ feature.
 =head1 SEE ALSO
 
 
-L<remove-pdf-password>.
-
 L<add-pdf-password>.
 
+L<remove-pdf-password>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
